from setuptools import setup, find_packages

setup(
    name="bell-lapadula",
    version="0.1",
    author="Kenjayev",
    author_email="shahzodkenjayevyangiboyevich@gmail.com",
    description="Bell-LaPadula modelini amalga oshirish",
    packages=find_packages(),
    install_requires=[
        # Kerakli kutubxonalar ro'yxati
    ],
)
